@@ -54,7 +54,7 @@ namespace libtorrent
 
 #ifndef TORRENT_NO_DEPRECATE
 	// information about a file in a file_storage
-	struct TORRENT_EXPORT file_entry
+	struct TORRENT_DEPRECATED_EXPORT file_entry
 	{
 		// hidden
 		file_entry();
@@ -253,7 +253,7 @@ namespace libtorrent
 			// this file has the executable attribute set.
 			attribute_executable = 4,
 
-			// this file is a symbilic link. It should have a link
+			// this file is a symbolic link. It should have a link
 			// target string associated with it.
 			attribute_symlink = 8
 		};
@@ -269,7 +269,7 @@ namespace libtorrent
 		// being added. This memory is *borrowed*, i.e. it is the caller's
 		// responsibility to make sure it stays valid throughout the lifetime
 		// of this file_storage object or any copy of it. The same thing applies
-		// to ``filehash``, wich is an optional pointer to a 20 byte binary
+		// to ``filehash``, which is an optional pointer to a 20 byte binary
 		// SHA-1 hash of the file.
 		// 
 		// if ``filename`` is NULL, the filename from ``path`` is used and not
@@ -530,6 +530,11 @@ namespace libtorrent
 		// to file at ``index``.
 		int file_flags(int index) const;
 
+		// returns true if the file at the specified index has been renamed to
+		// have an absolute path, i.e. is not anchored in the save path of the
+		// torrent.
+		bool file_absolute_path(int index) const;
+
 		// returns the index of the file at the given offset in the torrent
 		int file_index_at_offset(boost::int64_t offset) const;
 
